@@ -39,6 +39,10 @@ def get_parser():
         nargs   = "*",
         help    = "Packages to Upgrade."
     )
+    # parser.add_argument("--resolve",
+    #     action  = "store_true",
+    #     help    = "Resolve Dependencies"
+    # )
     parser.add_argument("--ignore",
         action  = "append",
         help    = "Ignore packages to upgrade."
@@ -177,7 +181,8 @@ def get_parser():
 
     parser.add_argument("-V", "--verbose",
         action  = "store_true",
-        help    = "Display verbose output."
+        help    = "Display verbose output.",
+        default = getenv("VERBOSE", False)
     )
     parser.add_argument("-v", "--version",
         action  = "version",
