@@ -207,7 +207,7 @@ def update_registry(registry,
 	packages = registry.packages
 
 	if filter_:
-		packages = [p for p in packages if p["name"] in filter_]
+		packages = [p for p in packages if p.name in filter_]
 	
 	table 	 = Table(header = ["Name", "Current Version", "Latest Version",
 		"Home Page"])
@@ -312,8 +312,9 @@ def update_registry(registry,
 			file = file)
 
 def get_registry_from_pip(pip_path, user = False, sync = False, outdated = True,
-	build_dependency_tree = False, jobs = 1, only_packages = [ ],
-	ignore_packages = [ ]):
+	build_dependency_tree = False, resolve = False, jobs = 1, only_packages = [ ],
+	ignore_packages = [ ], latest = False
+):
 	logger.info("Fetching installed packages for %s..." % pip_path)
 
 	_, output, _ = _pip.call("list", user = user, outdated = outdated, \
@@ -330,7 +331,8 @@ def get_registry_from_pip(pip_path, user = False, sync = False, outdated = True,
 	
 	registry     = Registry(source = pip_path, packages = packages,
 		installed = True, sync = sync,
-		build_dependency_tree = build_dependency_tree, jobs = jobs)
+		build_dependency_tree = build_dependency_tree, 
+		resolve = resolve, jobs = jobs, latest = latest)
 
 	logger.info("Packages within `pip` %s found: %s..." % (pip_path, registry.packages))
 	# _pip.get_installed_distributions() # https://github.com/achillesrasquinha/pipupgrade/issues/13
@@ -338,7 +340,8 @@ def get_registry_from_pip(pip_path, user = False, sync = False, outdated = True,
 	return registry
 
 def get_registry_from_requirements(requirements, sync = False, jobs = 1,
-	only_packages = [ ], file = None, ignore_packages = [ ]):
+	only_packages = [ ], resolve = False, file = None, ignore_packages = [ ],
+    latest = False):
 	path = osp.realpath(requirements)
 
 	if not osp.exists(path):
@@ -355,7 +358,7 @@ def get_registry_from_requirements(requirements, sync = False, jobs = 1,
 			packages = [p for p in packages if p["name"] not in ignore_packages]
 
 		registry = Registry(source = path, packages = packages, sync = sync,
-			jobs = jobs
+			resolve = resolve, jobs = jobs, latest = latest
 		)
 
 	logger.info("Packages within requirements %s found: %s..." % (
