@@ -6,7 +6,7 @@ import pipupgrade
 from   pipupgrade.util.types 	import auto_typecast
 from   pipupgrade._compat		import string_types
 
-PREFIX = "%s" % pipupgrade.__name__.upper()
+PREFIX 	= "%s" % pipupgrade.__name__.upper()
 
 def getenvvar(name, prefix = PREFIX, seperator = "_"):
 	if not prefix:
@@ -42,4 +42,8 @@ def value_to_envval(value):
 		else:
 			raise TypeError("Unknown parameter type %s with value %r" % (value, type(value)))
 
-	return value
\ No newline at end of file
+	return value
+
+SECRETS = (
+	getenvvar("JOBS_GITHUB_TOKEN"),
+)
\ No newline at end of file
