@@ -15,4 +15,7 @@ def test_pool():
         _assert(pool)
 
     with parallel.no_daemon_pool() as pool:
-        _assert(pool)
\ No newline at end of file
+        _assert(pool)
+
+        process = pool.Process()
+        assert process.daemon == False
\ No newline at end of file
